@@ -15,7 +15,7 @@ class VAPIDKeyset(models.Model):
     @property
     def public_key(self):
         key_str = self.private_key
-        if (not isinstance(self.private_key, bytes) ):
+        if isinstance(self.private_key, memoryview):
             key_str = key_str.tobytes()
         padding = len(key_str) % 4
         key_str += b"=" * padding
